@@ -72,7 +72,7 @@ QStringList *Kwave::FilterPlugin::setup(QStringList &previous_params)
 
     if (!m_params.isEmpty()) setup_dialog->setParams(m_params);
 
-    QStringList *list = new QStringList();
+    QStringList *list = new(std::nothrow) QStringList();
     Q_ASSERT(list);
     if (list && dlg->exec()) {
 	// user has pressed "OK"
@@ -96,7 +96,7 @@ void Kwave::FilterPlugin::run(QStringList params)
     if (!interpreteParameters(params)) m_params = params;
 
     sample_index_t first, last;
-    QList<unsigned int> tracks;
+    QVector<unsigned int> tracks;
     selection(&tracks, &first, &last, true);
 
     // switch to interactive mode in pre-listen mode
