@@ -50,16 +50,16 @@ namespace Kwave
     public:
 	/** Constructor */
 	explicit OverViewWidget(Kwave::SignalManager &signal,
-	                        QWidget *parent = 0);
+                                QWidget *parent = Q_NULLPTR);
 
 	/** Destructor */
-	virtual ~OverViewWidget();
+        virtual ~OverViewWidget() Q_DECL_OVERRIDE;
 
 	/** minimum size of the widget, @see QWidget::minimumSize() */
 	virtual QSize minimumSize() const;
 
 	/** optimal size for the widget, @see QWidget::sizeHint() */
-	QSize sizeHint() const Q_DECL_OVERRIDE;
+        virtual QSize sizeHint() const Q_DECL_OVERRIDE;
 
     public slots:
 
@@ -96,19 +96,19 @@ namespace Kwave
     protected:
 
 	/** refreshes the bitmap when resized */
-	void resizeEvent(QResizeEvent *) Q_DECL_OVERRIDE;
+        virtual void resizeEvent(QResizeEvent *) Q_DECL_OVERRIDE;
 
 	/**
 	 * On mouse move:
 	 * move the current viewport center to the clicked position.
 	 */
-	void mouseMoveEvent(QMouseEvent *) Q_DECL_OVERRIDE;
+        virtual void mouseMoveEvent(QMouseEvent *) Q_DECL_OVERRIDE;
 
 	/**
 	 * On single-click with the left mouse button:
 	 * move the current viewport center to the clicked position.
 	 */
-	void mousePressEvent(QMouseEvent *) Q_DECL_OVERRIDE;
+        virtual void mousePressEvent(QMouseEvent *) Q_DECL_OVERRIDE;
 
 	/**
 	 * On double click with the left mouse button, without shift:
@@ -119,7 +119,7 @@ namespace Kwave
 	 * The same as above, but zoom out instead of in
 	 * (by sending "view:zoom_out()").
 	 */
-	void mouseDoubleClickEvent(QMouseEvent *e) Q_DECL_OVERRIDE;
+        virtual void mouseDoubleClickEvent(QMouseEvent *e) Q_DECL_OVERRIDE;
 
     protected slots:
 
@@ -181,10 +181,10 @@ namespace Kwave
 	    explicit WorkerThread(Kwave::OverViewWidget *widget);
 
 	    /** destructor */
-	    virtual ~WorkerThread();
+            virtual ~WorkerThread() Q_DECL_OVERRIDE;
 
 	    /** thread function that calls calculateBitmap() */
-	    void run() Q_DECL_OVERRIDE;
+            virtual void run() Q_DECL_OVERRIDE;
 
 	private:
 
