@@ -24,6 +24,7 @@
 #include <QtGlobal>
 #include <QList>
 #include <QObject>
+#include <QVector>
 
 #include "libkwave/MultiTrackSource.h"
 #include "libkwave/SampleReader.h"
@@ -58,7 +59,7 @@ namespace Kwave
 	 */
 	MultiTrackReader(Kwave::ReaderMode mode,
 	                Kwave::SignalManager &signal_manager,
-	                const QList<unsigned int> &track_list,
+	                const QVector<unsigned int> &track_list,
 	                sample_index_t first, sample_index_t last);
 
 	/** Destructor */
