@@ -178,5 +178,11 @@ QString Kwave::urlScheme()
     return _("kwave");
 }
 
+//***************************************************************************
+quint64 Kwave::undoLimit()
+{
+    return 2048;
+}
+
 //***************************************************************************
 //***************************************************************************
