@@ -46,25 +46,25 @@ namespace Kwave
 	UndoInsertTrack(Kwave::Signal &signal, unsigned int track);
 
 	/** Destructor */
-	virtual ~UndoInsertTrack();
+        virtual ~UndoInsertTrack() Q_DECL_OVERRIDE;
 
 	/**
 	 * Returns a verbose short description of the action.
 	 */
-	QString description() Q_DECL_OVERRIDE;
+        virtual QString description() Q_DECL_OVERRIDE;
 
 	/** @see UndoAction::undoSize() */
-	qint64 undoSize() Q_DECL_OVERRIDE;
+        virtual qint64 undoSize() Q_DECL_OVERRIDE;
 
 	/** @see UndoAction::redoSize() */
-	qint64 redoSize() Q_DECL_OVERRIDE;
+        virtual qint64 redoSize() Q_DECL_OVERRIDE;
 
 	/** @see UndoAction::store() */
-	bool store(Kwave::SignalManager &manager) Q_DECL_OVERRIDE;
+        virtual bool store(Kwave::SignalManager &manager) Q_DECL_OVERRIDE;
 
 	/** @see UndoAction::undo() */
-	Kwave::UndoAction *undo(Kwave::SignalManager &manager,
-	                        bool with_redo) Q_DECL_OVERRIDE;
+        virtual Kwave::UndoAction *undo(Kwave::SignalManager &manager,
+	                                bool with_redo) Q_DECL_OVERRIDE;
 
     protected:
 
